#! /bin/csh

mkdir server
mkdir server/xlsamples
mkdir server/xlsamples/www
rm -rf server/xlsamples/www/gateway
cp -rf ../../../../www/gateway server/xlsamples/www
pushd server/xlsamples/www
find . -name 'CVS' -exec rm -rf {} \;
cd gateway

foreach a (packages/*/*)
	cp -rf base/* $a
	pushd $a

	chmod 0755 *.cgi
	chmod 0755 edit/*.cgi
	chmod 777 posted
	chmod 666 edit/postedNum.txt

	tar cvf ../update.tar .
	mv ../update.tar .
	popd
	cp -rf confs/* $a
	cp ../../../../../../../../doc/install/READMEs/www-gateway/* .
end

rm packages/skeleton/old/main.html
cp -rf except/skeleton.old.main.html packages/skeleton/old/main.html

popd
